package com.ruoyi.project.sems.safecheck.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.framework.aspectj.lang.annotation.DataScopePlant;
import com.ruoyi.project.sems.safecheck.domain.TSpecPersonweekcheck;

/**
 * 每周个人安全检查Mapper接口
 *
 * @author Li
 * @date 2023-08-29
 */
public interface TSpecPersonweekcheckMapper
{
    /**
     * 查询每周个人安全检查
     *
     * @param id 每周个人安全检查ID
     * @return 每周个人安全检查
     */
    public TSpecPersonweekcheck selectTSpecPersonweekcheckById(Long id);

    /**
     * 查询每周个人安全检查列表
     *
     * @param tSpecPersonweekcheck 每周个人安全检查
     * @return 每周个人安全检查集合
     */
    @DataScopePlant(deptAlias = "d")
    public List<TSpecPersonweekcheck> selectTSpecPersonweekcheckList(TSpecPersonweekcheck tSpecPersonweekcheck);

    List<TSpecPersonweekcheck> selectTSpecPersonweekcheckListByWeek(TSpecPersonweekcheck tSpecPersonweekcheck);
    /**
     * 新增每周个人安全检查
     *
     * @param tSpecPersonweekcheck 每周个人安全检查
     * @return 结果
     */
    public int insertTSpecPersonweekcheck(TSpecPersonweekcheck tSpecPersonweekcheck);

    /**
     * 修改每周个人安全检查
     *
     * @param tSpecPersonweekcheck 每周个人安全检查
     * @return 结果
     */
    public int updateTSpecPersonweekcheck(TSpecPersonweekcheck tSpecPersonweekcheck);

    /**
     * 删除每周个人安全检查
     *
     * @param id 每周个人安全检查ID
     * @return 结果
     */
    public int deleteTSpecPersonweekcheckById(Long id);

    /**
     * 批量删除每周个人安全检查
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSpecPersonweekcheckByIds(Long[] ids);


    int batchConfirmByids(Long[] ids);

    int batchCancel(Long[] ids);

    List<TSpecPersonweekcheck> selectMyList(TSpecPersonweekcheck tSpecPersonweekcheck);
}
